# -*- coding: utf-8 -*-

from sqlalchemy import Column, Sequence, Integer, ForeignKey
from sqlalchemy.types import TIMESTAMP
import datetime as dt
from olympo.util.constantes import BOOL_TRUE, BOOL_FALSE

# funciones    

def clase_codobjeto(id_clase):
    """
    def clase_codobjeto(int cod_clase)
    Devuelve una cadena formada por el nombre de la clase más 'COD_OBJETO'. Por ejemplo "OBJ_12345.COD_OBJETO"
    """
    return 'obj_%d.cod_objeto' % id_clase

def nombre_tabla(id_clase):
    """
    def nombre_tabla(int cod_clase)
    Devuelve el nombre de una tabla (OBJ_XXXX) que corresponde a la clase 'cod_clase'"""
    return 'obj_%d' % id_clase

def nombre_coleccion(clase):
    """
    def nombre_coleccion(int clase)
    Devuelve el nombre de la colección (COL_XXXX) de la clase 'clase'
    """
    return 'col_%d' % clase

def nombre_largo(clase, atributo):
    if isinstance(clase, int):
        return 'obj_%d_%s' % (clase, atributo.lower())
    else:
        return '%s_%d' % (clase, atributo.lower())

def cod_atributo(atributo):
    """
    def cod_atributo(str atributo)
    Devuelve el código de un atributo"""
    return int(atributo.upper().replace('ATR_', ''))

def cod_clase(clase):
    """
    def cod_clase(str clase)
    Devuelve el código de la clase 'clase' (OBJ_XXX)"""
    return int(clase.upper().replace('OBJ_', ''))

def cod_objeto(clase):
    """
    def cod_objeto(int clase)
    Devuelve el objeto 'Column' correspondiente al COD_OBJETO de la clase 'clase'""" 
    return Column('cod_objeto', Integer, Sequence('GEN_%d' % clase, increment=1), primary_key=True)

def atributo_objeto(atributo, clase_enlazada):
    """
    def atributo_objeto(str atributo, int clase_enlazada)
    Devuelve el objeto 'Column' correspondiente a un atributo tipo 'objeto' 
    enlazado a la clase 'clase_enlazada'
    """
    return Column(atributo, Integer, ForeignKey(clase_codobjeto(clase_enlazada)))

def fecha_de_creacion(atributo):
    """
    def fecha_de_creacion(str atributo)
    Devuelve un objeto 'Column' para el atributo 'atributo' configurado como
    un atributo 'Fecha de Creación'"""
    return Column(atributo, TIMESTAMP, default=dt.datetime.now())

def fecha_de_actualizacion(atributo):
    """
    def fecha_de_actualizacion(str atributo)
    Devuelve un objeto 'Column' para el atributo 'atributo' configurado como
    un atributo 'Fecha de Actualización'"""    
    return Column(atributo, TIMESTAMP, onupdate=dt.datetime.now(), default=dt.datetime.now())

class valor_logico(object):
    
    def __init__(self, field):
        # 1, 2 ó None        
        self.field = field
        
    def __get__(self, instance, cls):
        
        valor = getattr(instance, self.field) 
        
        if valor == BOOL_TRUE:
            return True
        
        elif valor == BOOL_FALSE:
            return False
        
        else:
            return None        
    
    def __set__(self, instance, valor):
                
        if valor is None:
            setattr(instance, self.field, None)
        else:
            if valor:
                setattr(instance, self.field, BOOL_TRUE)
            else:
                setattr(instance, self.field, BOOL_FALSE)
    
#def sin_espacios(cadena):
#    """
#    def sin_espacios(str cadena)
#    Devuelve una cadena en minúsculas, sin espacios y cambiando las letras acentuadas 
#    por su correspondiente sin acentuar
#    """
#    
#    cadena = str(cadena.encode('utf-8')).lower().replace(' ', '_')
#    
#    #print 'cadena =', cadena, type(cadena)
#                
#    anterior = '_'
#    resultado = ''            
#    for c in cadena:
#        if c in ['á', 'é', 'í', 'ó', 'ú', 'ü', 'ñ'] or str(c).isalpha() or str(c).isdigit():
#            if c == 'á':
#                c = 'a'
#            elif c == 'é':
#                c = 'e'
#            elif c == 'í': 
#                c = 'i'
#            elif c == 'ó':
#                c = 'o'
#            elif c in ['ú', 'ü']:
#                c = 'u'
#            elif c == 'ñ':
#                c = 'n'
#        else:
#            c = '_'
#            
#        if anterior == '_':
#            c = c.upper()
#        
#        if c != '_':
#            resultado += c
#        
#        anterior = c
#    
#    print 'resultado =', resultado
#    return resultado
#
#def calcular_funcionfecha(funcion):
#    
#    FF_FECHA = 0
#    FF_INICIO_SEMANA = 1
#    FF_INICIO_MES = 2
#    FF_INICIO_MES_ANTERIOR = 3
#    FF_INICIO_TRIMESTRE = 4
#    FF_INICIO_ANYO = 5
#    FF_FIN_SEMANA = 6
#    FF_FIN_MES = 7
#    FF_FIN_MES_ANTERIOR = 8
#    FF_FIN_TRIMESTRE = 9
#    FF_FIN_ANYO = 10
#    FF_INICIO_SEMANA_ANTERIOR = 11
#    FF_FIN_SEMANA_ANTERIOR = 12
#    FF_INICIO_SEMANA_SIGUIENTE = 13
#    FF_FIN_SEMANA_SIGUIENTE = 14
#
#    valor = ''
#    hoy = datetime.today()
#    if funcion == FF_FECHA:
#        valor = 'CURRENT_DATE'
#    elif funcion == FF_INICIO_SEMANA:
#        valor = datetime.fromordinal(hoy.toordinal() - hoy.weekday()).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_INICIO_MES:
#        valor = datetime(hoy.year, hoy.month, 1).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_INICIO_MES_ANTERIOR:
#        if hoy.month == 1:
#            anyo = hoy.year - 1
#            mes = 12
#        else:
#            anyo = hoy.year
#            mes = hoy.month - 1
#            
#        valor = datetime(anyo, mes, 1).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_INICIO_TRIMESTRE:
#        trimestre = (hoy.month - 1) / 3 + 1
#        
#        if trimestre == 1:
#            inicio = datetime(hoy.year, 1, 1)
#        elif trimestre == 2:
#            inicio = datetime(hoy.year, 4, 1)
#        elif trimestre == 3:
#            inicio = datetime(hoy.year, 7, 1)
#        else:
#            inicio = datetime(hoy.year, 10, 1)
#            
#        valor = inicio.strftime('%Y/%m/%d')
#    
#    elif funcion == FF_INICIO_ANYO:
#        valor = datetime(hoy.year, 1, 1).strftime('%Y/%m/%d')
#        
#    elif funcion == FF_FIN_SEMANA:
#        valor = datetime.fromordinal(hoy.toordinal() + 6 - hoy.weekday()).strftime('%Y/%m/%d') 
#    
#    elif funcion == FF_FIN_MES:
#        if hoy.month == 12:
#            anyo = hoy.year + 1
#            mes = 1
#        else:
#            anyo = hoy.year
#            mes = hoy.month + 1
#            
#        # un día menos del día 1 del mes siguiente
#        valor = datetime.fromordinal(datetime(anyo, mes, 1).toordinal() - 1).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_FIN_MES_ANTERIOR:
#        # un día antes del inicio de este mes (mes de hoy)        
#        valor = datetime.fromordinal(datetime(hoy.year, hoy.month, 1).toordinal() -1)
#    
#    elif funcion == FF_FIN_TRIMESTRE:
#        trimestre = (hoy.month - 1) / 3 + 1
#        
#        if trimestre == 1:
#            inicio = datetime(hoy.year, 3, 31)
#        elif trimestre == 2:
#            inicio = datetime(hoy.year, 6, 30)
#        elif trimestre == 3:
#            inicio = datetime(hoy.year, 9, 30)
#        else:
#            inicio = datetime(hoy.year, 12, 31)
#            
#        valor = inicio.strftime('%Y/%m/%d')
#    
#    elif funcion == FF_FIN_ANYO:
#        hoy = datetime.today()
#        valor = datetime(hoy.year, 12, 31).strftime('%Y/%m/%d')
#        
#    elif funcion == FF_INICIO_SEMANA_ANTERIOR:
#        valor = datetime.fromordinal(hoy.toordinal() - 7 - hoy.weekday()).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_FIN_SEMANA_ANTERIOR:
#        valor = datetime.fromordinal(hoy.toordinal() - 1 - hoy.weekday()).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_INICIO_SEMANA_SIGUIENTE:
#        valor = datetime.fromordinal(hoy.toordinal() + 7 - hoy.weekday()).strftime('%Y/%m/%d')
#    
#    elif funcion == FF_FIN_SEMANA_SIGUIENTE:
#        valor = datetime.fromordinal(hoy.toordinal() + 13 - hoy.weekday()).strftime('%Y/%m/%d')
#    
#    return valor
#
#def calcular_funcionentero(funcion):
#    
#    FE_DIA = 0
#    FE_MES = 1
#    FE_ANYO = 2
#    
#    hoy = datetime.today()
#    
#    if funcion == FE_DIA:
#        valor = str(hoy.day)
#    
#    elif funcion == FE_MES:
#        valor = str(hoy.month)
#    
#    elif funcion == FE_ANYO:
#        valor = str(hoy.year)
#    
#    return valor
#
#def operador_insensitive(filtro, operador, valor, tipo_dato):
#    
#    CC_INCLUYE = 0
#    CC_NOINCLUYE = 1
#    CC_EMPIEZAPOR = 2
#    CC_MENOR = 3
#    CC_MAYOR = 4
#    CC_IGUAL = 5
#    CC_DISTINTO = 6
#    CC_MAYORIGUAL = 7
#    CC_MENORIGUAL = 8
##    CC_TERMINAPOR = 9
#    CC_ULTIMOSDIAS = 10
#    CC_PROXIMOSDIAS = 11
#    
#    funciones_fecha = ['<Fecha>', \
#                       '<InicioSemana>', \
#                       '<InicioMes>', \
#                       '<InicioMesAnterior>', \
#                       '<InicioTrimestre>', \
#                       '<InicioAño>', \
#                       '<FinSemana>', \
#                       '<FinMes>', \
#                       '<FinMesAnterior>', \
#                       '<FinTrimestre>', \
#                       '<FinAño>', \
#                       '<InicioSemanaAnterior>', \
#                       '<FinSemanaAnterior>', \
#                       '<InicioSemanaSiguiente>', \
#                       '<FinSemanaSiguiente>']    
#    
#    funciones_entero = ['<Dia>', \
#                        '<Mes>', \
#                        '<Año>']
#  
#    resultado = ''
#    if valor == '':
#        resultado = filtro
#        if operador == CC_INCLUYE or operador == CC_EMPIEZAPOR or \
#        operador == CC_IGUAL:
#            resultado = '(' + resultado + ' IS NULL '
#          
#            if tipo_dato == FBString:            
#                resultado = resultado + " OR %s = '')" % filtro
#            else:
#                resultado += ')'
#                
#        elif operador == CC_NOINCLUYE:  resultado += ' IS NOT NULL'
#        elif operador == CC_MENOR:      resultado += " < ''"
#        elif operador == CC_MAYOR:      resultado += " > ''"
#        elif operador == CC_DISTINTO:   resultado += ' IS NOT NULL'
#        elif operador == CC_MAYORIGUAL: resultado += " >= ''"
#        elif operador == CC_MENORIGUAL: resultado += " <= ''"
#        
#    else:        
#        # fechas
#        if tipo_dato == FBDate: # isinstance(tipo_dato, FBDate): # tipo_datos == 'date':
#            if operador != CC_ULTIMOSDIAS and operador != CC_PROXIMOSDIAS:
#                try:
#                    l = map(lambda f: f.upper(), funciones_fecha)
#                    i = l.index(str(valor).upper())
#                    
#                    # calcular el valor de la función de fecha i
#                    valor = str(valor).replace(valor, calcular_funcionfecha(i))
#                except:
#                    # 'valor' no está en la lista de funciones
#                    if isinstance(valor, datetime):
#                        fecha = valor.date()
#                        hora = valor.time()
#                        if fecha.year == 1900 and fecha.month == 1 and fecha.day == 1:
#                            valor = hora.strftime('%H:%M')
#                        else:
#                            valor = fecha.strftime('%Y/%m/%d')
#            
#            resultado = filtro
#            
#            # operadores 
#            if operador == CC_INCLUYE:        resultado += " = '%s'" % valor
#            elif operador == CC_NOINCLUYE:    resultado += " <> '%s'" % valor
#            elif operador == CC_EMPIEZAPOR:   resultado += " >= '%s'" % valor
#            elif operador == CC_MENOR:        resultado += " < '%s'" %  valor
#            elif operador == CC_MAYOR:        resultado += " > '%s'"  % valor
#            elif operador == CC_IGUAL:        resultado += " = '%s'" % valor
#            elif operador == CC_DISTINTO:     resultado += " <> '%s'" % valor
#            elif operador == CC_MAYORIGUAL:   resultado += " >= '%s'" % valor
#            elif operador == CC_MENORIGUAL:   resultado += " <= '%s'" % valor
#            elif operador == CC_ULTIMOSDIAS:  resultado += " >= ('%s') AND (%s <= CURRENT_DATE)" % (valor.strftime('%Y/%m/%d'), filtro)
#            elif operador == CC_PROXIMOSDIAS: resultado += " >= CURRENT_DATE AND %s <= ('%s')" % (filtro, valor.strftime('%Y/%m/%d')) 
#            
#        # cadena
#        elif tipo_dato == FBString:
#            
#            resultado = 'UPPER(%s)' % filtro
#            valor = valor.upper()            
#                
#            # operadores            
#            if operador == CC_INCLUYE:        resultado += " Like '%" + valor + "%'"
#            elif operador == CC_NOINCLUYE:    resultado += " Not Like '%" + valor + "%'"
#            elif operador == CC_EMPIEZAPOR:   resultado += " Like '" + valor + "%'"
#            elif operador == CC_MENOR:        resultado += " < '%s'" % valor
#            elif operador == CC_MAYOR:        resultado += " > '%s'" % valor
#            elif operador == CC_IGUAL:        resultado += " = '%s'" % valor
#            elif operador == CC_DISTINTO:     resultado += " <> '%s'" % valor
#            elif operador == CC_MAYORIGUAL:   resultado += " >= '%s'" % valor
#            elif operador == CC_MENORIGUAL:   resultado += " <= '%s'" % valor
#            elif operador == CC_ULTIMOSDIAS:  resultado += " >= ('%s') AND (%s <= CURRENT_DATE)" % (valor.strftime('%Y/%m/%d'), filtro)
#            elif operador == CC_PROXIMOSDIAS: resultado += " >= CURRENT_DATE AND %s <= ('%s')" % (filtro, valor.strftime('%Y/%m/%d'))
#
#        else:
#            # entero
#            if tipo_dato == FBInteger:
#                resultado = filtro
#            else:
#                # real
#                resultado = 'CAST(%s as NUMERIC(9, 2))' % filtro
#            
#            try:
#                l = map(lambda f: f.upper(), funciones_entero)
#                i = l.index(str(valor).upper())
#                
#                valor = str(valor).replace(str(valor), calcular_funcionentero(i))
#            except ValueError:
#                pass
#
#            # tratar valor para quitar separador de miles (creo que no hace falta)
#            
#            valor = str(valor).replace(',', '.')
#                
#            # operadores            
#            if operador == CC_INCLUYE:      resultado += " Like '%" + valor + "%'"
#            elif operador == CC_NOINCLUYE:  resultado += " Not Like '%" + valor + "%'"
#            elif operador == CC_EMPIEZAPOR: resultado += " Like '" + valor + "%'"
#            elif operador == CC_MENOR:      resultado += ' < %s' % valor
#            elif operador == CC_MAYOR:      resultado += ' > %s' % valor
#            elif operador == CC_IGUAL:      resultado += ' = %s' % valor
#            elif operador == CC_DISTINTO:   resultado += ' <> %s' % valor
#            elif operador == CC_MAYORIGUAL: resultado += ' >= %s' % valor
#            elif operador == CC_MENORIGUAL: resultado += ' <= %s' % valor
#            
#    return resultado

def tratar_memo(cadena):
    """
    Devuelve la cadena, que está codificada en ISO-8859-1 (como en Olympo), a su
    versión en UTF-8. Si cadena es nulo devuelve '' (cadena vacía)
    
    IN
      cadena <str>
      
    OUT
      <str>
    """
    if cadena is None:
        return ''
    
    else:
        return cadena.decode('windows-1252').encode('utf-8')


# -*- coding: utf-8 -*-

from olympo.model.const_olympo import cl_Clases, clas_fechadecreacion, \
    clas_fechadeactualizacion, cl_Atributos, atri_fechadecreacion, \
    atri_fechadeactualizacion, clas_usuario, cl_Usuarios, atri_usuario, \
    usua_fechadecreacion, usua_fechadeactualizacion, usua_usuario, clas_nombre, \
    clas_descripcion, atri_nombre, atri_descripcion, atri_tamano, atri_clase, \
    atri_clasedeatributoenlazado, cl_Documentos, docu_fechadecreacion, \
    docu_fechadeactualizacion, docu_usuario, docu_autor, docu_formato, docu_tipo, \
    cl_FormatosDeDocumento, cl_TiposDeDocumento, fdd_fechadecreacion, \
    fdd_fechadeactualizacion, fdd_usuario, cl_UsuariosWeb, uswe_fechadecreacion, \
    uswe_fechadeactualizacion, uswe_usuario, cl_RepositoriosDeDocumentos, \
    cl_TiposDeValor, cl_TiposDeAtributo, atri_tipodevalor, atri_tipodeatributo, \
    tdv_fechadecreacion, tdv_fechadeactualizacion, tdv_usuario, tdv_nombre, \
    tdv_descripcion, tda_nombre, tda_descripcion, tda_fechadecreacion, \
    tda_fechadeactualizacion, tda_usuario, usua_nombre, docu_titulo, docu_notas, \
    usua_administrador, docu_privado
from olympo.util.util import nombre_tabla, cod_objeto, fecha_de_creacion, \
    fecha_de_actualizacion, atributo_objeto, valor_logico
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relation
from sqlalchemy.schema import Column
from sqlalchemy.types import Unicode, Text, Integer
    
DeclarativeBase = declarative_base()

class Clases(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_Clases)
    
    id_ = cod_objeto(cl_Clases)
    fecha_de_creacion_ = fecha_de_creacion(clas_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(clas_fechadeactualizacion)
    
    nombre = Column(clas_nombre, Unicode)
    descripcion = Column(clas_descripcion, Text)
    
    id_usuario = atributo_objeto(clas_usuario, cl_Usuarios)
    
class Atributos(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_Atributos)
    
    id_ = cod_objeto(cl_Atributos)
    fecha_de_creacion_ = fecha_de_creacion(atri_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(atri_fechadeactualizacion)
    
    nombre = Column(atri_nombre, Unicode)
    descripcion = Column(atri_descripcion, Text)
    tamano = Column(atri_tamano, Integer)
    
    id_usuario = atributo_objeto(atri_usuario, cl_Usuarios)
    
    id_clase = atributo_objeto(atri_clase, cl_Clases)
    id_clase_enlazada = atributo_objeto(atri_clasedeatributoenlazado, cl_Clases)
    id_tipo_de_valor = atributo_objeto(atri_tipodevalor, cl_TiposDeValor)
    id_tipo_de_atributo = atributo_objeto(atri_tipodeatributo, cl_TiposDeAtributo)
    
Clases.atributos = relation('Atributos', backref='clase',
                            primaryjoin=Clases.id_ == Atributos.id_clase)

Clases.atributos_enlazados = relation('Atributos', backref='clase_enlazada',
                                      primaryjoin=Clases.id_ == Atributos.id_clase_enlazada)

class TiposDeValor(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_TiposDeValor)
    
    id_ = cod_objeto(cl_TiposDeValor)
    fecha_de_creacion_ = fecha_de_creacion(tdv_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(tdv_fechadeactualizacion)
    
    nombre = Column(tdv_nombre, Unicode)
    descripcion = Column(tdv_descripcion, Text)
    
    id_usuario = atributo_objeto(tdv_usuario, cl_Usuarios)
    
    atributos = relation('Atributos', backref='tipo_de_valor')
    
class TiposDeAtributo(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_TiposDeAtributo)
    
    id_ = cod_objeto(cl_TiposDeAtributo)
    fecha_de_creacion_ = fecha_de_creacion(tda_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(tda_fechadeactualizacion)
    
    nombre = Column(tda_nombre, Unicode)
    descripcion = Column(tda_descripcion, Text)
    
    id_usuario = atributo_objeto(tda_usuario, cl_Usuarios)

class Usuarios(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_Usuarios)
    
    id_ = cod_objeto(cl_Usuarios)
    fecha_de_creacion_ = fecha_de_creacion(usua_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(usua_fechadeactualizacion)
    
    nombre = Column(usua_nombre, Unicode)
    administrador = valor_logico(usua_administrador)
    
    id_usuario = atributo_objeto(usua_usuario, cl_Usuarios)
    
class Documentos(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_Documentos)
    
    id_ = cod_objeto(cl_Documentos)
    fecha_de_creacion_ = fecha_de_creacion(docu_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(docu_fechadeactualizacion)
    
    titulo = Column(docu_titulo, Unicode)
    notas = Column(docu_notas, Text)
    privado = valor_logico(docu_privado)
    
    id_autor = atributo_objeto(docu_autor, cl_Usuarios)
    id_formato = atributo_objeto(docu_formato, cl_FormatosDeDocumento)
    id_tipo = atributo_objeto(docu_tipo, cl_TiposDeDocumento)
    
    id_usuario = atributo_objeto(docu_usuario, cl_Usuarios)
    
class FormatosDeDocumentos(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_FormatosDeDocumento)
    
    id_ = cod_objeto(cl_FormatosDeDocumento)
    fecha_de_creacion_ = fecha_de_creacion(fdd_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(fdd_fechadeactualizacion)
    
    id_usuario = atributo_objeto(fdd_usuario, cl_Usuarios)
    
class TiposDeDocumento(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_TiposDeDocumento)
    
    id_ = cod_objeto(cl_TiposDeDocumento)
    
class RepositoriosDeDocumentos(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_RepositoriosDeDocumentos)
    
    id_ = cod_objeto(cl_RepositoriosDeDocumentos)
    
class UsuariosWeb(DeclarativeBase):
    
    __tablename__ = nombre_tabla(cl_UsuariosWeb)
    
    id_ = cod_objeto(cl_UsuariosWeb)
    fecha_de_creacion_ = fecha_de_creacion(uswe_fechadecreacion)
    fecha_de_actualizacion_ = fecha_de_actualizacion(uswe_fechadeactualizacion)
    
    id_usuario = atributo_objeto(uswe_usuario, cl_Usuarios)
    


# -*- coding: utf-8 -*-

from setuptools import setup

setup(name='Olympo',
      version='0.0.3',
      author=u'León Domingo',
      author_email='leon.domingo@ender.es',
      description=('A little set of utilities to manage Olympo projects'),
      #license=???,
      keywords='ender olympo',
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Utilities',
      ],
      url='http://www.ender.es',      
      packages=['olympo',
                'olympo.model',
                'olympo.util',
      ],
#      package_data={
#            'olympo': ['default/*.*', 
#                      ],
#            #'neptuno.templates': ['*.xml'],
#      },
      install_requires=[
        #'kinterbasdb',
        'SQLAlchemy==0.7.5',
        'lxml',
        'xlrd',
        'xlwt',
        'simplejson==2.2.0',
        'jinja2',
      ],
     )



# -*- coding: utf-8 -*-

cl_Clases = 1

clas_fechadecreacion = 'atr_1'
clas_fechadeactualizacion = 'atr_2'
clas_usuario = 'atr_3'
clas_nombre = 'atr_4'
clas_descripcion = 'atr_5'
clas_atributos = 'atr_6'
clas_atributosdevista = 'atr_7'
clas_atributosenlazados = 'atr_8'
clas_metodos = 'atr_94'
clas_grupos = 'atr_130'
clas_favoritos = 'atr_143'
clas_objetoscondocumentosasociados = 'atr_221'
clas_consultas = 'atr_269'
clas_tablasdeconsulta = 'atr_285'
clas_usuarios = 'atr_422'
clas_filtrosdeclaseenvariables = 'atr_3147'
clas_icono = 'atr_100528'
clas_parametrosquelausanparaseleccionarvalor = 'atr_100277'
clas_estructural = 'atr_100013'
clas_vistaspersonalizadas = 'atr_100058'
clas_indicadores = 'atr_100554'
clas_procesosprogramados = 'atr_100313'
clas_tareaspendientes = 'atr_100353'
clas_textostraducidos = 'atr_100508'

cl_Atributos = 2

atri_fechadecreacion = 'atr_9'
atri_fechadeactualizacion = 'atr_10'
atri_usuario = 'atr_11'
atri_nombre = 'atr_12'
atri_clase = 'atr_13'
atri_tipodeatributo = 'atr_14'
atri_tipodevalor = 'atr_15'
atri_atributoenlazado = 'atr_16'
atri_clasedeatributoenlazado = 'atr_17'
atri_descripcion = 'atr_18'
atri_privilegios = 'atr_19'
atri_requerido = 'atr_97'
atri_unico = 'atr_99'
atri_tablasdeconsulta = 'atr_289'
atri_filtrosdeconsulta = 'atr_309'
atri_relacionesdeconsulta = 'atr_329'
atri_consultas = 'atr_355'
atri_tamano = 'atr_380'
atri_relacionesdevistaspersonalizadas = 'atr_100083'
atri_filtrospordefecto = 'atr_100132'
atri_vistaspersonalizadas = 'atr_100066'
atri_estructural = 'atr_100427'
atri_textostraducidos = 'atr_100510'

cl_Usuarios = 3

usua_fechadecreacion = 'atr_20'
usua_fechadeactualizacion = 'atr_21'
usua_usuario = 'atr_22'
usua_nombre = 'atr_23'
usua_login = 'atr_24'
usua_descripcion = 'atr_25'
usua_administrador = 'atr_26'
usua_clases = 'atr_27'
usua_atributos = 'atr_28'
usua_usuarios = 'atr_29'
usua_usuarioscreadoresdeprivilegios = 'atr_30'
usua_privilegios = 'atr_31'
usua_tiposdeatributo = 'atr_32'
usua_valoreslogicos = 'atr_33'
usua_tiposdevalor = 'atr_34'
usua_atributosdevista = 'atr_36'
usua_usuariosdeatributosdevista = 'atr_37'
usua_metodoscreados = 'atr_95'
usua_grupos = 'atr_111'
usua_gruposdelusuario = 'atr_126'
usua_favoritos = 'atr_135'
usua_tiposdedocumento = 'atr_149'
usua_formatosdedocumento = 'atr_153'
usua_estadosdedocumento = 'atr_157'
usua_repositoriosdedocumentos = 'atr_161'
usua_documentos = 'atr_165'
usua_relacionobjetosdocumentos = 'atr_215'
usua_consultas = 'atr_245'
usua_nivelesdeacceso = 'atr_239'
usua_tablasdeconsulta = 'atr_249'
usua_camposdeconsulta = 'atr_253'
usua_filtrosdeconsulta = 'atr_257'
usua_tiposdetabladeconsulta = 'atr_261'
usua_relacionesdeconsulta = 'atr_265'
usua_procesosprogramados = 'atr_100289'
usua_parametrosdeconsulta = 'atr_333'
usua_consultasdelusuario = 'atr_347'
usua_ordenaciondecampos = 'atr_363'
usua_filtrospordefecto = 'atr_385'
usua_variables = 'atr_409'
usua_metodos = 'atr_418'
usua_clasesdelusuario = 'atr_423'
usua_mostraravisosobligatoriamente = 'atr_100524'
usua_objetofiltrado = 'atr_3164'
usua_vistaspersonalizadasenpropiedad = 'atr_100064'
usua_avisos = 'atr_100337'
usua_nivelesdeprivilegio = 'atr_35'
usua_relacionesdevistaspersonalizadas = 'atr_100076'
usua_puertosmtp = 'atr_100455'
usua_usartls = 'atr_100457'
usua_tiposdemetodo = 'atr_3151'
usua_vistaspersonalizadas = 'atr_100040'
usua_camposdevistaspersonalizadas = 'atr_100044'
usua_vistasdeusuario = 'atr_100107'
usua_indicadores = 'atr_100146'
usua_formatolistafavoritosuser = 'atr_100179'
usua_gestiondocumental = 'atr_100175'
usua_indicadoresdelusuario = 'atr_100558'
usua_valoresdeindicadores = 'atr_100562'
usua_sesiones = 'atr_100596'
usua_registrodeutilizacion = 'atr_100227'
usua_correoelectronico = 'atr_3971'
usua_puedevervistaspersonalizadas = 'atr_100619'
usua_puedegestionarlosfavoritos = 'atr_100629'
usua_puedeverdocumentos = 'atr_100623'
usua_gruposdeusuarios = 'atr_100373'
usua_numerodediasparacaducidadtarea = 'atr_100358'
usua_avisosdelusuario = 'atr_100365'
usua_gruposdeusuariosalosquepertenece = 'atr_100379'
usua_idiomas = 'atr_100391'
usua_idiomaactivo = 'atr_100402'
usua_remitentesms = 'atr_100459'
usua_usuariosweb = 'atr_100468'
usua_servidorsmtp = 'atr_100431'
usua_nombredeusuarioemail = 'atr_100435'
usua_passwordemail = 'atr_100439'
usua_textostraducidos = 'atr_100492'
usua_puedeverexploraciondedatos = 'atr_100625'
usua_registrodeactividad = 'atr_100658'
usua_numerodediaspreavisopordefecto = 'atr_100356'
usua_idiomaactivo2 = 'atr_100382'
usua_usuarioswebcomoperfil = 'atr_100472'

cl_PrivilegiosDeAtributo = 4

pda_fechadecreacion = 'atr_38'
pda_fechadeactualizacion = 'atr_39'
pda_usuario = 'atr_40'
pda_atributo = 'atr_41'
pda_usuariodelatributo = 'atr_42'
pda_ordencorto = 'atr_43'
pda_ordenlargo = 'atr_44'
pda_niveldeprivilegio = 'atr_45'
pda_altura = 'atr_82'
pda_anchura = 'atr_83'
pda_posiciondesdelaizquierda = 'atr_84'
pda_posiciondesdearriba = 'atr_85'

cl_ValoresLogicos = 5

valo_fechadecreacion = 'atr_46'
valo_fechadeactualizacion = 'atr_47'
valo_usuario = 'atr_48'
valo_valor = 'atr_49'
valo_administradores = 'atr_50'
valo_atributosdevistavisibles = 'atr_51'
valo_atributosrequeridos = 'atr_98'
valo_atributosunicos = 'atr_100'
valo_gruposbase = 'atr_128'
valo_documentosprivados = 'atr_227'
valo_filtrosconparametro = 'atr_311'
valo_filtrosatodosloscampos = 'atr_3133'
valo_usuariosquedebenverlosavisosobligatoriamente = 'atr_100525'
valo_clasesestructurales = 'atr_100014'
valo_usartlsenconexionemailusuarios = 'atr_100458'
valo_vistasespeciales = 'atr_100111'
valo_filtrospordefectoparentesisabierto = 'atr_100136'
valo_filtrospordefectoparentesiscerrado = 'atr_100138'
valo_usuarioscongestiondocumental = 'atr_100176'
valo_licencia = 'atr_100190'
valo_tablasdeconsultaconfiltradoanulado = 'atr_100543'
valo_camposdeconsultarequeridos = 'atr_100551'
valo_indicadoresqueincrementanvaloresparciales = 'atr_100576'
valo_consultasfastreport = 'atr_100269'
valo_procesosprogramados = 'atr_100301'
valo_procesosprogramadostodoslosdias = 'atr_100317'
valo_camposdeconsultaeliminarnulos = 'atr_303'
valo_usuariosquepuedenvervistaspersonalizadas = 'atr_100620'
valo_metodoscreacionpordefecto = 'atr_100329'
valo_metodosedicionpordefecto = 'atr_100331'
valo_metodosborradopordefecto = 'atr_100333'
valo_avisoscompletados = 'atr_100369'
valo_idiomasactivos = 'atr_100407'
valo_metodosaejecutaralarrancarproteo = 'atr_100464'
valo_metodosquesobreescribeneleditordecolecciones = 'atr_100419'
valo_atributosestructurales = 'atr_100428'
valo_usuariosquepuedenverdocumentos = 'atr_100624'
valo_usuariosquepuedengestionarlosfavoritos = 'atr_100630'
valo_usuariosquepuedenverexploraciondedatos = 'atr_100626'
valo_activarregistrodeactividad = 'atr_100670'

cl_TiposDeValor = 6

tdv_fechadecreacion = 'atr_53'
tdv_fechadeactualizacion = 'atr_54'
tdv_usuario = 'atr_55'
tdv_nombre = 'atr_56'
tdv_descripcion = 'atr_57'
tdv_atributos = 'atr_58'

cl_TiposDeAtributo = 7

tda_fechadecreacion = 'atr_59'
tda_fechadeactualizacion = 'atr_60'
tda_usuario = 'atr_61'
tda_nombre = 'atr_62'
tda_descripcion = 'atr_63'
tda_atributos = 'atr_64'

cl_NivelesDePrivilegio = 8

ndp_fechadecreacion = 'atr_65'
ndp_fechadeactualizacion = 'atr_66'
ndp_nombre = 'atr_68'
ndp_descripcion = 'atr_69'
ndp_privilegiosdeatributo = 'atr_70'
ndp_nivelesdeacceso = 'atr_241'
ndp_usuario = 'atr_67'

cl_AtributosDeVista = 9

adv_fechadecreacion = 'atr_71'
adv_fechadeactualizacion = 'atr_72'
adv_usuario = 'atr_73'
adv_clase = 'atr_74'
adv_usuariodevista = 'atr_75'
adv_nombredelacolumna = 'atr_76'
adv_posicion = 'atr_77'
adv_visible = 'atr_78'
adv_anchura = 'atr_80'
adv_titulodelacolumna = 'atr_81'
adv_ordenacion = 'atr_372'
adv_filtrospordefecto = 'atr_389'
adv_vistapersonalizada = 'atr_100054'
adv_posicionparaordenacion = 'atr_100252'

cl_Metodos = 10

meto_fechadecreacion = 'atr_86'
meto_fechadeactualizacion = 'atr_87'
meto_usuario = 'atr_88'
meto_clase = 'atr_89'
meto_nombre = 'atr_90'
meto_fichero = 'atr_91'
meto_funcionnumero = 'atr_92'
meto_version = 'atr_93'
meto_usuarios = 'atr_419'
meto_especificacion = 'atr_3124'
meto_identificador = 'atr_3126'
meto_fechaversion = 'atr_3128'
meto_procesosprogramados = 'atr_100297'
meto_textostraducidos = 'atr_100533'
meto_tipodemetodo = 'atr_3157'
meto_creacionpordefecto = 'atr_100328'
meto_edicionpordefecto = 'atr_100330'
meto_borradopordefecto = 'atr_100332'
meto_icono = 'atr_100414'
meto_ejecutaralarrancarproteo = 'atr_100463'
meto_sobreescribeeleditordecolecciones = 'atr_100418'

cl_Grupos = 23

grup_usuario = 'atr_110'
grup_fechadecreacion = 'atr_112'
grup_fechadeactualizacion = 'atr_113'
grup_nombre = 'atr_117'
grup_propietario = 'atr_125'
grup_grupobase = 'atr_127'
grup_clases = 'atr_129'
grup_grupopadre = 'atr_131'
grup_gruposhijos = 'atr_132'
grup_textostraducidos = 'atr_100537'

cl_Favoritos = 25

favo_usuario = 'atr_134'
favo_fechadecreacion = 'atr_136'
favo_fechadeactualizacion = 'atr_137'
favo_nombre = 'atr_138'
favo_notas = 'atr_140'
favo_clase = 'atr_142'
favo_objeto = 'atr_144'
favo_top = 'atr_100421'
favo_left = 'atr_100423'

cl_TiposDeDocumento = 26

tdd_usuario = 'atr_148'
tdd_fechadecreacion = 'atr_150'
tdd_fechadeactualizacion = 'atr_151'
tdd_nombre = 'atr_168'
tdd_descripcion = 'atr_170'
tdd_documentos = 'atr_174'

cl_FormatosDeDocumento = 27

fdd_usuario = 'atr_152'
fdd_fechadecreacion = 'atr_154'
fdd_fechadeactualizacion = 'atr_155'
fdd_nombre = 'atr_178'
fdd_descripcion = 'atr_190'
fdd_extension = 'atr_192'
fdd_documentos = 'atr_194'

cl_EstadosDeDocumento = 28

edd_usuario = 'atr_156'
edd_fechadecreacion = 'atr_158'
edd_fechadeactualizacion = 'atr_159'
edd_nombre = 'atr_182'
edd_descripcion = 'atr_184'
edd_documentos = 'atr_186'

cl_RepositoriosDeDocumentos = 29

rdd_usuario = 'atr_160'
rdd_fechadecreacion = 'atr_162'
rdd_fechadeactualizacion = 'atr_163'
rdd_nombre = 'atr_206'
rdd_ruta = 'atr_208'
rdd_documentos = 'atr_210'

cl_Documentos = 30

docu_usuario = 'atr_164'
docu_fechadecreacion = 'atr_166'
docu_fechadeactualizacion = 'atr_167'
docu_tipo = 'atr_175'
docu_estado = 'atr_187'
docu_formato = 'atr_195'
docu_titulo = 'atr_198'
docu_version = 'atr_200'
docu_autor = 'atr_202'
docu_repositorio = 'atr_211'
docu_objetosincluidos = 'atr_219'
docu_privado = 'atr_226'
docu_nivelesdeacceso = 'atr_100123'
docu_palabrasclave = 'atr_100183'
docu_notas = 'atr_100185'

cl_RelacionObjetosDocumentos = 32

reob_usuario = 'atr_214'
reob_fechadecreacion = 'atr_216'
reob_fechadeactualizacion = 'atr_217'
reob_documento = 'atr_218'
reob_clase = 'atr_220'
reob_codigodeobjeto = 'atr_222'

cl_NivelesDeAcceso = 33

nda_usuario = 'atr_230'
nda_fechadecreacion = 'atr_232'
nda_fechadeactualizacion = 'atr_233'
nda_nombre = 'atr_234'
nda_descripcion = 'atr_236'
nda_usuariosdelnivel = 'atr_238'
nda_niveldeprivilegio = 'atr_240'
nda_documentos = 'atr_100124'

cl_Consultas = 34

cons_usuario = 'atr_244'
cons_fechadecreacion = 'atr_246'
cons_fechadeactualizacion = 'atr_247'
cons_clase = 'atr_268'
cons_nombre = 'atr_270'
cons_especificacion = 'atr_272'
cons_fichero = 'atr_274'
cons_version = 'atr_276'
cons_tablas = 'atr_281'
cons_parametros = 'atr_337'
cons_usuarios = 'atr_346'
cons_atributosutilizados = 'atr_354'
cons_identificador = 'atr_3136'
cons_fechaversion = 'atr_3138'
cons_utilizarfastreport = 'atr_100268'
cons_icono = 'atr_100410'

cl_TablasDeConsulta = 35

tdc_usuario = 'atr_248'
tdc_fechadecreacion = 'atr_250'
tdc_fechadeactualizacion = 'atr_251'
tdc_consulta = 'atr_280'
tdc_nombre = 'atr_282'
tdc_clase = 'atr_284'
tdc_tipodetabla = 'atr_286'
tdc_atributo = 'atr_288'
tdc_campos = 'atr_295'
tdc_orden = 'atr_100284'
tdc_filtros = 'atr_307'
tdc_ordensql = 'atr_100017'
tdc_textosql = 'atr_100009'
tdc_parametrosquelausanparaseleccionarvalor = 'atr_100275'
tdc_filtrostablasql = 'atr_100019'
tdc_anularfiltradoporelementoseleccionado = 'atr_100542'

cl_CamposDeConsulta = 36

cdc_usuario = 'atr_252'
cdc_fechadecreacion = 'atr_254'
cdc_fechadeactualizacion = 'atr_255'
cdc_tabla = 'atr_294'
cdc_nombre = 'atr_296'
cdc_expresion = 'atr_298'
cdc_relaciones = 'atr_327'
cdc_filtros = 'atr_351'
cdc_ordenacion = 'atr_369'
cdc_campomaster = 'atr_100280'
cdc_numerodeorden = 'atr_3692'
cdc_requerido = 'atr_100550'
cdc_camposdetail = 'atr_100281'
cdc_utilizarcodobjetotablacolecciones = 'atr_302'

cl_FiltrosDeConsulta = 37

fdc_usuario = 'atr_256'
fdc_fechadecreacion = 'atr_258'
fdc_fechadeactualizacion = 'atr_259'
fdc_tabla = 'atr_306'
fdc_atributo = 'atr_308'
fdc_usaparametro = 'atr_310'
fdc_operador = 'atr_312'
fdc_valor = 'atr_314'
fdc_enlaceconanterior = 'atr_316'
fdc_relaciones = 'atr_325'
fdc_parametro = 'atr_343'
fdc_campo = 'atr_350'
fdc_aplicaratodosloscampos = 'atr_3132'

cl_TiposDeTablaDeConsulta = 38

tdtdc_usuario = 'atr_260'
tdtdc_fechadecreacion = 'atr_262'
tdtdc_fechadeactualizacion = 'atr_263'
tdtdc_tablasdeconsulta = 'atr_287'
tdtdc_nombre = 'atr_320'

cl_RelacionesDeConsulta = 39

rdc_usuario = 'atr_264'
rdc_fechadecreacion = 'atr_266'
rdc_fechadeactualizacion = 'atr_267'
rdc_filtro = 'atr_324'
rdc_campo = 'atr_326'
rdc_atributoderelacion = 'atr_328'

cl_ParametrosDeConsulta = 41

pdc_usuario = 'atr_332'
pdc_fechadecreacion = 'atr_334'
pdc_fechadeactualizacion = 'atr_335'
pdc_consulta = 'atr_336'
pdc_nombre = 'atr_338'
pdc_valorpordefecto = 'atr_340'
pdc_filtros = 'atr_342'
pdc_orden = 'atr_100272'
pdc_tablaparaseleccionarvalor = 'atr_100274'
pdc_claseparaseleccionarvalor = 'atr_100276'

cl_OrdenacionDeCampos = 42

odc_usuario = 'atr_362'
odc_fechadecreacion = 'atr_364'
odc_fechadeactualizacion = 'atr_365'
odc_descripcion = 'atr_366'
odc_campos = 'atr_368'
odc_columnasdevista = 'atr_373'

cl_FiltrosPorDefecto = 43

fpd_usuario = 'atr_384'
fpd_fechadecreacion = 'atr_386'
fpd_fechadeactualizacion = 'atr_387'
fpd_columna = 'atr_388'
fpd_operador = 'atr_390'
fpd_valor = 'atr_398'
fpd_enlace = 'atr_404'
fpd_relacion = 'atr_100127'
fpd_atributo = 'atr_100131'
fpd_parentesisabierto = 'atr_100135'
fpd_parentesiscerrado = 'atr_100137'
fpd_vista = 'atr_100141'

cl_Variables = 44

vari_usuario = 'atr_408'
vari_fechadecreacion = 'atr_410'
vari_fechadeactualizacion = 'atr_411'
vari_rutaconsultas = 'atr_412'
vari_rutametodos = 'atr_414'
vari_remitentesms = 'atr_100520'
vari_versiondemodelo = 'atr_100001'
vari_clasefiltrada = 'atr_3146'
vari_logotipointerface = 'atr_3574'
vari_nombredeusuariosms = 'atr_100514'
vari_contrasenasms = 'atr_100516'
vari_nombrecliente = 'atr_3805'
vari_urlhudson = 'atr_100447'
vari_nombreaplicacion = 'atr_100102'
vari_prefijoparametodos = 'atr_100579'
vari_licencia = 'atr_100189'
vari_logotipoinformes = 'atr_5252'
vari_direccioncliente = 'atr_5256'
vari_telefonocliente = 'atr_5258'
vari_emailcliente = 'atr_5260'
vari_urlmodelodedatos = 'atr_100443'
vari_logotipoaplicacion = 'atr_100320'
vari_paginaweb = 'atr_5461'
vari_activarregistrodeactividad = 'atr_100669'

cl_RelacionesDeVistasPersonalizadas = 100004

rdvp_usuario = 'atr_100075'
rdvp_fechadecreacion = 'atr_100077'
rdvp_fechadeactualizacion = 'atr_100078'
rdvp_vista = 'atr_100080'
rdvp_atributo = 'atr_100082'
rdvp_orden = 'atr_100084'
rdvp_camposdevista = 'atr_100114'
rdvp_relacionanterior = 'atr_100118'
rdvp_relacionesposteriores = 'atr_100119'
rdvp_filtrospordefecto = 'atr_100128'

cl_Sesiones = 100024

sesi_usuario = 'atr_100595'
sesi_fechadecreacion = 'atr_100597'
sesi_fechadeactualizacion = 'atr_100598'
sesi_direccionip = 'atr_100599'
sesi_challenge = 'atr_100607'
sesi_usuarioweb = 'atr_100615'
sesi_fechadecaducidad = 'atr_100633'

cl_ValoresDeIndicadores = 100022

vdi_codobjetofiltrado = 'atr_100581'
vdi_usuario = 'atr_100561'
vdi_fechadecreacion = 'atr_100563'
vdi_fechadeactualizacion = 'atr_100564'
vdi_indicador = 'atr_100565'
vdi_fechayhora = 'atr_100567'
vdi_nombredeserie = 'atr_100569'
vdi_valor = 'atr_100571'

cl_VistasPersonalizadas = 100001

vipe_usuario = 'atr_100039'
vipe_fechadecreacion = 'atr_100041'
vipe_fechadeactualizacion = 'atr_100042'
vipe_atributosdevista = 'atr_100053'
vipe_clasebase = 'atr_100057'
vipe_campos = 'atr_100059'
vipe_nombre = 'atr_100061'
vipe_propietario = 'atr_100063'
vipe_relaciones = 'atr_100081'
vipe_usuarios = 'atr_100106'
vipe_especial = 'atr_100110'
vipe_textosql = 'atr_100121'
vipe_filtrospordefecto = 'atr_100142'
vipe_indicadores = 'atr_100152'
vipe_textoordencorto = 'atr_100254'
vipe_identificador = 'atr_100256'
vipe_version = 'atr_100258'
vipe_fechaversion = 'atr_100260'
vipe_nombredefichero = 'atr_100266'
vipe_relacionesatributos = 'atr_100065'

cl_CamposDeVistasPersonalizadas = 100002

cdvp_usuario = 'atr_100043'
cdvp_fechadecreacion = 'atr_100045'
cdvp_fechadeactualizacion = 'atr_100046'
cdvp_expresion = 'atr_100069'
cdvp_nombre = 'atr_100073'
cdvp_vista = 'atr_100060'
cdvp_relacionesdevista = 'atr_100115'

cl_TiposDeMetodo = 156

tdm_usuario = 'atr_3150'
tdm_fechadecreacion = 'atr_3152'
tdm_fechadeactualizacion = 'atr_3153'
tdm_nombre = 'atr_3154'
tdm_metodos = 'atr_3156'

cl_Indicadores = 100007

indi_clase = 'atr_100553'
indi_usuario = 'atr_100145'
indi_fechadecreacion = 'atr_100147'
indi_fechadeactualizacion = 'atr_100148'
indi_nombre = 'atr_100149'
indi_vistapersonalizada = 'atr_100151'
indi_incrementalvaloresparciales = 'atr_100575'
indi_usuarios = 'atr_100557'
indi_descripcion = 'atr_100591'
indi_indicadoresdenivelinferior = 'atr_100585'
indi_indicadoresdenivelsuperior = 'atr_100586'
indi_expresion = 'atr_100587'
indi_valores = 'atr_100566'

cl_RegistroDeActividad = 100029

rda_usuario = 'atr_100657'
rda_fechadecreacion = 'atr_100659'
rda_fechadeactualizacion = 'atr_100660'
rda_descripcion = 'atr_100661'
rda_puntodecontrol = 'atr_100663'
rda_fechayhora = 'atr_100665'

cl_RegistroDeUtilizacion = 100010

rdu_usuario = 'atr_100226'
rdu_fechadecreacion = 'atr_100228'
rdu_fechadeactualizacion = 'atr_100229'
rdu_apertura = 'atr_100230'
rdu_ultimaactualizacion = 'atr_100232'
rdu_aplicacion = 'atr_100234'
rdu_equipo = 'atr_100236'
rdu_otrosdatos = 'atr_100238'

cl_ProcesosProgramados = 100012

prpr_usuario = 'atr_100288'
prpr_fechadecreacion = 'atr_100290'
prpr_fechadeactualizacion = 'atr_100291'
prpr_fecha = 'atr_100292'
prpr_hora = 'atr_100294'
prpr_metodo = 'atr_100296'
prpr_ejecutable = 'atr_100298'
prpr_ejecutado = 'atr_100300'
prpr_resultado = 'atr_100302'
prpr_descripcion = 'atr_100306'
prpr_parametros = 'atr_100308'
prpr_claseorigendelproceso = 'atr_100312'
prpr_objetoorigendelproceso = 'atr_100314'
prpr_todoslosdias = 'atr_100316'

cl_Avisos = 100014

avis_tag = 'atr_100546'
avis_usuario = 'atr_100336'
avis_texto = 'atr_100451'
avis_fechadecreacion = 'atr_100338'
avis_fechadeactualizacion = 'atr_100339'
avis_descripcion = 'atr_100342'
avis_fecha = 'atr_100344'
avis_fechadecaducidad = 'atr_100348'
avis_codobjetoasociado = 'atr_100350'
avis_clasedeobjetoasociado = 'atr_100352'
avis_fechainiciodeaviso = 'atr_100362'
avis_usuariosdelaviso = 'atr_100364'
avis_color = 'atr_100386'
avis_completada = 'atr_100368'

cl_GruposDeUsuarios = 100015

gdu_usuario = 'atr_100372'
gdu_fechadecreacion = 'atr_100374'
gdu_fechadeactualizacion = 'atr_100375'
gdu_nombre = 'atr_100376'
gdu_usuarios = 'atr_100378'

cl_IdiomasOlympo = 100016

idol_usuario = 'atr_100390'
idol_fechadecreacion = 'atr_100392'
idol_fechadeactualizacion = 'atr_100393'
idol_nombre = 'atr_100394'
idol_codigo = 'atr_100396'
idol_icono = 'atr_100398'
idol_usuariosconidiomapordefecto = 'atr_100403'
idol_activo = 'atr_100406'
idol_textostraducidos = 'atr_100512'

cl_UsuariosWeb = 100018

uswe_rol = 'atr_100611'
uswe_sesiones = 'atr_100616'
uswe_usuario = 'atr_100467'
uswe_fechadecreacion = 'atr_100469'
uswe_fechadeactualizacion = 'atr_100470'
uswe_usuarioperfil = 'atr_100471'
uswe_nombredeusuario = 'atr_100477'
uswe_contrasena = 'atr_100479'
uswe_nombre = 'atr_100481'
uswe_ultimologin = 'atr_100487'

cl_TextosTraducidos = 100019

tetr_grupo = 'atr_100536'
tetr_metodo = 'atr_100532'
tetr_usuario = 'atr_100491'
tetr_fechadecreacion = 'atr_100493'
tetr_fechadeactualizacion = 'atr_100494'
tetr_texto = 'atr_100505'
tetr_clase = 'atr_100507'
tetr_atributo = 'atr_100509'
tetr_idioma = 'atr_100511'

